#!/bin/sh

# copying all the needed stuff in place.
DOTFILES=${HOME}/.dotfiles

# copying zshrc file
if [[ ! -f "$HOME/.zshrc" ]]; then
  # no first setup done

  # Determining operating system so we can quickly setup basic configuration
  if grep -qi 'debian' /proc/version; then
    # Debian
    sudo apt install -y zsh-autosuggestions zsh-syntax-highlighting
    ln -sf ${DOTFILES}/zsh/distro/debian.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi
  if grep -qi 'ubuntu' /proc/version; then
    # TODO: complete instructions for Ubuntu
    ln -sf ${DOTFILES}/zsh/distro/ubuntu.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi
  if grep -qi 'manjaro' /proc/version; then
    # TODO: complete instructions for Manjaro
    pamac install manjaro-zsh-config
    ln -sf ${DOTFILES}/zsh/distro/manjaro.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi
  if grep -qi 'archlinux' /proc/version; then
    pacman -S zsh-autosuggestions zsh-syntax-highlighting
    ln -sf ${DOTFILES}/zsh/distro/archlinux.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi
  if grep -qi 'voidlinux' /proc/version; then
    xbps-install -S zsh
    ln -sf ${DOTFILES}/zsh/distro/void.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi
  if [[ -f /etc/redhat-release ]] && grep -qi centos /etc/redhat-release; then
    # TODO: installation on centos.
    ln -sf ${DOTFILES}/zsh/distro/centos.base.zsh ${DOTFILES}/zsh/distro.base.zsh
  fi

  cp "${DOTFILES}/zshrc" "$HOME/.zshrc"
  
  if [[ -f ${DOTFILES}/zsh/antibody_plugins.txt ]]; then
    # Installing natively on archlinux, manjaro
    if grep -i archlinux /proc/version || grep -i manjaro /proc/version; then
      yay -S --no-confirm antibody-bin
    else
      curl -sfL git.io/antibody | sudo sh -s - -b /usr/local/bin
    fi
    
    mkdir -p ~/.zsh/conf.d
    antibody bundle < ${DOTFILES}/zsh/antibody_plugins.txt > ~/.zsh/conf.d/000_antibody.zsh
fi

# Copying tmux configuration file and initialize plugins.
if [[ ! -f "$HOME/.tmux.conf" ]]; then
  mkdir -p ${HOME}/.config/tmux/plugins
  git clone https://github.com/tmux-plugins/tpm ${HOME}/.config/tmux/plugins/tpm
  ln -sf  "${DOTFILES}/tmux.conf" "$HOME/.config/tmux/tmux.conf"
  echo "Please, open Tmux and run 'prefix I'."
fi

# Vim - configure vundle and install plugins.
if [[ ! -f "${HOME}/.vimrc" ]]; then
  ln -sf ${DOTFILES}/vimrc ${HOME}/.vimrc
  ln -sf ${DOTFILES}/vim ${HOME}/.vim
  # Installing vim-plug
  curl -fLo ~/.vim/autoload/plug.vim --create-dirs \
    https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
  # Installing vim-plug and relative plugins
  vim +PlugInstall +qall
fi
